==> sped-1.35.26.tar.gz: sped-1.35.26/pythonsped/efd/blocos.py <==
# -*- coding: utf-8 -*-
# from pythonsped.efd.blocos.bloco_arquivo import registro_0000

from bloco_9 import *
from bloco_0 import *
from bloco_1 import *
from bloco_b import *
from bloco_c import *
from bloco_d import *
from bloco_e import *
from bloco_g import *
from bloco_h import *
from bloco_k import *
from pythonsped.utils import TrackedAttributesClass


class bloco_arquivo(TrackedAttributesClass):
    """Classe do Blocos"""

    class registro_0000(TrackedAttributesClass):
        """
        REGISTRO 0000: ABERTURA DO ARQUIVO DIGITAL E IDENTIFICAÇÃO DA ENTIDADE
        Registro obrigatório e corresponde ao primeiro registro do arquivo.
        """
        _order = []

        def __init__(self):
            super(bloco_arquivo.registro_0000, self).__init__()
            self.REG = '0000'  #criar referencia na classe blocos - C
            self.nivel_h = 0  #nível
            self.pai = ''
            self.ocorrencia = '1'  #ocorrência por arquivo
            self.COD_VER = ''  #versão do leiaute --100, 101, 102 -N
            self.COD_FIN = ''  #Código da finalidade do arquivo: 0 - Remessa do arquivo original / 1 - Remessa do arquivo substituto. -N
            self.DT_INI = ''  #Data inicial das informações contidas no arquivo - N
            self.DT_FIN = ''  #Data final das informações contidas no arquivo - N
            self.NOME = ''  #Nome empresarial do contribuinte: - C
            self.CNPJ = ''  #Número de inscrição do contribuinte -N
            self.CPF = ''  #Número de inscrição do contribuinte: - N
            self.UF = ''  #Sigla da unidade da federação -C
            self.IE = ''  #Inscrição Estadual do Contribuinte -C
            self.COD_MUN = ''  #Código do município do domicílio fiscal -N
            self.IM = ''  #Inscrição municipal do contribuinte -C
            self.SUFRAMA = ''  #Número de inscrição do contribuinte: -C
            self.IND_PERFIL = ''  #Perfil de apresentado do arquivo fiscal: A - Perfil A / B - Perfil B / C - Perfil C -C
            self.IND_ATIV = ''  #N- Indicador de tipo de atividade: 0 - Industrial ou equiparado a industrial; 1 - Outros. -N
            self.registro_0001 = []
            self.registro_0990 = []
            self.registro_1001 = []
            self.registro_1990 = []
            self.registro_9001 = []
            self.registro_9990 = []
            self.registro_B001 = []
            self.registro_B990 = []
            self.registro_C001 = []
            self.registro_C990 = []
            self.registro_D001 = []
            self.registro_D990 = []
            self.registro_E001 = []
            self.registro_E990 = []
            self.registro_G001 = []
            self.registro_G990 = []
            self.registro_H001 = []
            self.registro_H990 = []
            self.registro_K001 = []
            self.registro_K990 = []
            self.fieldnames = ('REG', 'COD_VER', 'COD_FIN', 'DT_INI', 'DT_FIN', 'NOME', 'CNPJ',
                               'CPF', 'UF', 'IE', 'COD_MUN', 'IM', 'SUFRAMA', 'IND_PERFIL',
                               'IND_ATIV')
            self.formato = self.get_formato()

    def monta_arquivo(self, caminho='/tmp/', salvar_disco=False):
        # Escrevendo blocos totalizadores
        # ordem=('0','B','C','D','E','G','H','1','9')
        main = TrackedAttributesClass()
        if main.conta_registro['bloco_0']:
            reg_0990 = bloco_0.registro_0990()
            reg_0990.QTD_LIN_0 = main.conta_registro['bloco_0'] + 1
            reg_0990.write_line()
        if main.conta_registro['bloco_1']:
            reg_C990 = bloco_c.registro_C990()
            reg_C990.QTD_LIN_C = main.conta_registro['bloco_c'] + 1
            reg_C990.write_line()
        if main.conta_registro.get('bloco_b'):
            reg_B990 = bloco_b.registro_B990()
            reg_B990.QTD_LIN_B = main.conta_registro['bloco_b'] + 1
            reg_B990.write_line()
        if main.conta_registro['bloco_d']:
            reg_D990 = bloco_d.registro_D990()
            reg_D990.QTD_LIN_D = main.conta_registro['bloco_d'] + 1
            reg_D990.write_line()
        if main.conta_registro['bloco_e']:
            reg_E990 = bloco_e.registro_E990()
            reg_E990.QTD_LIN_E = main.conta_registro['bloco_e'] + 1
            reg_E990.write_line()
        if main.conta_registro['bloco_g']:
            reg_G990 = bloco_g.registro_G990()
            reg_G990.QTD_LIN_G = main.conta_registro['bloco_g'] + 1
            reg_G990.write_line()
        if main.conta_registro['bloco_h']:
            reg_H990 = bloco_h.registro_H990()
            reg_H990.QTD_LIN_H = main.conta_registro['bloco_h'] + 1
            reg_H990.write_line()
        if main.conta_registro.get('bloco_k'):
            reg_K990 = bloco_k.registro_K990()
            reg_K990.QTD_LIN_K = main.conta_registro['bloco_k'] + 1 if main.conta_registro[
                'bloco_k'] else 0
            reg_K990.write_line()
        if main.conta_registro['bloco_1']:
            reg_1990 = bloco_1.registro_1990()
            reg_1990.QTD_LIN_1 = main.conta_registro['bloco_1'] + 1
            reg_1990.write_line()

        linhas_arquivo = 0
        qt_9900 = 0
        qt_registros = main.quantidade_registros.copy()
        qt_registros['9990'] = 1
        for x in qt_registros:  # lançando totais de registros no registro 9900
            reg_9900 = bloco_9.registro_9900()
            reg_9900.REG_BLC = x
            reg_9900.QTD_REG_BLC = qt_registros[x]
            reg_9900.write_line()
            linhas_arquivo += qt_registros[x]
            qt_9900 += 1

        reg_9900 = bloco_9.registro_9900()
        reg_9900.REG_BLC = '9900'
        reg_9900.QTD_REG_BLC = qt_9900 + 2
        reg_9900.write_line()

        reg_9900 = bloco_9.registro_9900()
        reg_9900.REG_BLC = '9999'
        reg_9900.QTD_REG_BLC = 1
        reg_9900.write_line()
        #        #quantidade de registros do bloco 9
        reg_9990 = bloco_9.registro_9990()
        reg_9990.QTD_LIN_9 = qt_9900 + 5
        reg_9990.write_line()
        # fechamento do arquivo
        reg_9999 = bloco_9.registro_9999()
        reg_9999.QTD_LIN = linhas_arquivo + qt_9900 + 3
        reg_9999.write_line()

        # abrindo e fechando arquivo 0000/9999

        bloc_0, bloc_b, bloc_c, bloc_d, bloc_e, bloc_g, bloc_h, bloc_k, bloc_1, bloc_9 = \
            [], [], [], [], [], [], [], [], [], []

        for r in main.processos:
            if r.startswith('|0'):
                bloc_0.append(r)  # Adiciona todos os registros instanciados do bloco 0 em primeiro
                # nivel
            if r.startswith('|B'):
                bloc_b.append(r)
            if r.startswith('|C'):
                bloc_c.append(r)
            if r.startswith('|D'):
                bloc_d.append(r)
            if r.startswith('|E'):
                bloc_e.append(r)
            if r.startswith('|G'):
                bloc_g.append(r)
            if r.startswith('|H'):
                bloc_h.append(r)
            if r.startswith('|K'):
                bloc_k.append(r)
            if r.startswith('|1'):
                bloc_1.append(r)
            if r.startswith('|9'):
                bloc_9.append(r)
                bloc_9.sort()
        proc = bloc_0 + bloc_b + bloc_c + bloc_d + bloc_e + bloc_g + bloc_h + bloc_k + bloc_1 + \
            bloc_9
        result = ''.join(proc)
        # esvaziando informações
        main.processos[:] = []
        main.quantidade_registros.clear()
        main.conta_registro.clear()
        main.conta_registro['bloco_0'] = 0
        main.conta_registro['bloco_b'] = 0
        main.conta_registro['bloco_c'] = 0
        main.conta_registro['bloco_d'] = 0
        main.conta_registro['bloco_e'] = 0
        main.conta_registro['bloco_g'] = 0
        main.conta_registro['bloco_h'] = 0
        main.conta_registro['bloco_k'] = 0
        main.conta_registro['bloco_1'] = 0
        main.conta_registro['bloco_9'] = 0
        return result

==> sped-3.0.4.tar.gz: sped-3.0.4/pythonsped/efd/blocos.py <==
# -*- coding: utf-8 -*-
# from pythonsped.efd.blocos.bloco_arquivo import registro_0000

from .bloco_9 import *
from .bloco_0 import *
from .bloco_1 import *
from .bloco_b import *
from .bloco_c import *
from .bloco_d import *
from .bloco_e import *
from .bloco_g import *
from .bloco_h import *
from .bloco_k import *
from ..utils import TrackedAttributesClass


class bloco_arquivo(TrackedAttributesClass):
    """Classe do Blocos"""

    class registro_0000(TrackedAttributesClass):
        """
        REGISTRO 0000: ABERTURA DO ARQUIVO DIGITAL E IDENTIFICAÇÃO DA ENTIDADE
        Registro obrigatório e corresponde ao primeiro registro do arquivo.
        """
        _order = []

        def __init__(self):
            super(bloco_arquivo.registro_0000, self).__init__()
            self.REG = '0000'  #criar referencia na classe blocos - C
            self.nivel_h = 0  #nível
            self.pai = ''
            self.ocorrencia = '1'  #ocorrência por arquivo
            self.COD_VER = ''  #versão do leiaute --100, 101, 102 -N
            self.COD_FIN = ''  #Código da finalidade do arquivo: 0 - Remessa do arquivo original / 1 - Remessa do arquivo substituto. -N
            self.DT_INI = ''  #Data inicial das informações contidas no arquivo - N
            self.DT_FIN = ''  #Data final das informações contidas no arquivo - N
            self.NOME = ''  #Nome empresarial do contribuinte: - C
            self.CNPJ = ''  #Número de inscrição do contribuinte -N
            self.CPF = ''  #Número de inscrição do contribuinte: - N
            self.UF = ''  #Sigla da unidade da federação -C
            self.IE = ''  #Inscrição Estadual do Contribuinte -C
            self.COD_MUN = ''  #Código do município do domicílio fiscal -N
            self.IM = ''  #Inscrição municipal do contribuinte -C
            self.SUFRAMA = ''  #Número de inscrição do contribuinte: -C
            self.IND_PERFIL = ''  #Perfil de apresentado do arquivo fiscal: A - Perfil A / B - Perfil B / C - Perfil C -C
            self.IND_ATIV = ''  #N- Indicador de tipo de atividade: 0 - Industrial ou equiparado a industrial; 1 - Outros. -N
            self.registro_0001 = []
            self.registro_0990 = []
            self.registro_1001 = []
            self.registro_1990 = []
            self.registro_9001 = []
            self.registro_9990 = []
            self.registro_B001 = []
            self.registro_B990 = []
            self.registro_C001 = []
            self.registro_C990 = []
            self.registro_D001 = []
            self.registro_D990 = []
            self.registro_E001 = []
            self.registro_E990 = []
            self.registro_G001 = []
            self.registro_G990 = []
            self.registro_H001 = []
            self.registro_H990 = []
            self.registro_K001 = []
            self.registro_K990 = []
            self.fieldnames = ('REG', 'COD_VER', 'COD_FIN', 'DT_INI', 'DT_FIN', 'NOME', 'CNPJ',
                               'CPF', 'UF', 'IE', 'COD_MUN', 'IM', 'SUFRAMA', 'IND_PERFIL',
                               'IND_ATIV')
            self.formato = self.get_formato()

    def monta_arquivo(self, caminho='/tmp/', salvar_disco=False):
        # Escrevendo blocos totalizadores
        # ordem=('0','B','C','D','E','G','H','1','9')
        main = TrackedAttributesClass()
        if main.conta_registro['bloco_0']:
            reg_0990 = bloco_0.registro_0990()
            reg_0990.QTD_LIN_0 = main.conta_registro['bloco_0'] + 1
            reg_0990.write_line()
        if main.conta_registro['bloco_1']:
            reg_C990 = bloco_c.registro_C990()
            reg_C990.QTD_LIN_C = main.conta_registro['bloco_c'] + 1
            reg_C990.write_line()
        if main.conta_registro.get('bloco_b'):
            reg_B990 = bloco_b.registro_B990()
            reg_B990.QTD_LIN_B = main.conta_registro['bloco_b'] + 1
            reg_B990.write_line()
        if main.conta_registro['bloco_d']:
            reg_D990 = bloco_d.registro_D990()
            reg_D990.QTD_LIN_D = main.conta_registro['bloco_d'] + 1
            reg_D990.write_line()
        if main.conta_registro['bloco_e']:
            reg_E990 = bloco_e.registro_E990()
            reg_E990.QTD_LIN_E = main.conta_registro['bloco_e'] + 1
            reg_E990.write_line()
        if main.conta_registro['bloco_g']:
            reg_G990 = bloco_g.registro_G990()
            reg_G990.QTD_LIN_G = main.conta_registro['bloco_g'] + 1
            reg_G990.write_line()
        if main.conta_registro['bloco_h']:
            reg_H990 = bloco_h.registro_H990()
            reg_H990.QTD_LIN_H = main.conta_registro['bloco_h'] + 1
            reg_H990.write_line()
        if main.conta_registro.get('bloco_k'):
            reg_K990 = bloco_k.registro_K990()
            reg_K990.QTD_LIN_K = main.conta_registro['bloco_k'] + 1 if main.conta_registro[
                'bloco_k'] else 0
            reg_K990.write_line()
        if main.conta_registro['bloco_1']:
            reg_1990 = bloco_1.registro_1990()
            reg_1990.QTD_LIN_1 = main.conta_registro['bloco_1'] + 1
            reg_1990.write_line()

        linhas_arquivo = 0
        qt_9900 = 0
        qt_registros = main.quantidade_registros.copy()
        qt_registros['9990'] = 1
        for x in qt_registros:  # lançando totais de registros no registro 9900
            reg_9900 = bloco_9.registro_9900()
            reg_9900.REG_BLC = x
            reg_9900.QTD_REG_BLC = qt_registros[x]
            reg_9900.write_line()
            linhas_arquivo += qt_registros[x]
            qt_9900 += 1

        reg_9900 = bloco_9.registro_9900()
        reg_9900.REG_BLC = '9900'
        reg_9900.QTD_REG_BLC = qt_9900 + 2
        reg_9900.write_line()

        reg_9900 = bloco_9.registro_9900()
        reg_9900.REG_BLC = '9999'
        reg_9900.QTD_REG_BLC = 1
        reg_9900.write_line()
        #        #quantidade de registros do bloco 9
        reg_9990 = bloco_9.registro_9990()
        reg_9990.QTD_LIN_9 = qt_9900 + 5
        reg_9990.write_line()
        # fechamento do arquivo
        reg_9999 = bloco_9.registro_9999()
        reg_9999.QTD_LIN = linhas_arquivo + qt_9900 + 3
        reg_9999.write_line()

        # abrindo e fechando arquivo 0000/9999

        bloc_0, bloc_b, bloc_c, bloc_d, bloc_e, bloc_g, bloc_h, bloc_k, bloc_1, bloc_9 = \
            [], [], [], [], [], [], [], [], [], []

        for r in main.processos:
            if r.startswith('|0'):
                bloc_0.append(r)  # Adiciona todos os registros instanciados do bloco 0 em primeiro
                # nivel
            if r.startswith('|B'):
                bloc_b.append(r)
            if r.startswith('|C'):
                bloc_c.append(r)
            if r.startswith('|D'):
                bloc_d.append(r)
            if r.startswith('|E'):
                bloc_e.append(r)
            if r.startswith('|G'):
                bloc_g.append(r)
            if r.startswith('|H'):
                bloc_h.append(r)
            if r.startswith('|K'):
                bloc_k.append(r)
            if r.startswith('|1'):
                bloc_1.append(r)
            if r.startswith('|9'):
                bloc_9.append(r)
                bloc_9.sort()
        proc = bloc_0 + bloc_b + bloc_c + bloc_d + bloc_e + bloc_g + bloc_h + bloc_k + bloc_1 + \
            bloc_9
        result = ''.join(proc)
        # esvaziando informações
        main.processos[:] = []
        main.quantidade_registros.clear()
        main.conta_registro.clear()
        main.conta_registro['bloco_0'] = 0
        main.conta_registro['bloco_b'] = 0
        main.conta_registro['bloco_c'] = 0
        main.conta_registro['bloco_d'] = 0
        main.conta_registro['bloco_e'] = 0
        main.conta_registro['bloco_g'] = 0
        main.conta_registro['bloco_h'] = 0
        main.conta_registro['bloco_k'] = 0
        main.conta_registro['bloco_1'] = 0
        main.conta_registro['bloco_9'] = 0
        return result
